@@ -6,6 +6,12 @@ if spec is None:
     pass  # If faiss hasn't been installed. Just skip
 else:
     import faiss
+    faiss_metric_map = {
+        "l2": faiss.METRIC_L2,
+        "dot": faiss.METRIC_INNER_PRODUCT,
+        "angular": faiss.METRIC_INNER_PRODUCT,
+    }
+
 
 import numpy as np
 
@@ -13,6 +19,7 @@ from .opq import OPQ
 from .pq import PQ
 
 
+
 def nanopq_to_faiss(pq_nanopq):
     """Convert a :class:`nanopq.PQ` instance to `faiss.IndexPQ <https://github.com/facebookresearch/faiss/blob/master/IndexPQ.h>`_.
     To use this function, `faiss module needs to be installed <https://github.com/facebookresearch/faiss/blob/master/INSTALL.md>`_.
@@ -31,7 +38,7 @@ def nanopq_to_faiss(pq_nanopq):
     D = pq_nanopq.Ds * pq_nanopq.M
     nbits = {np.uint8: 8, np.uint16: 16, np.uint32: 32}[pq_nanopq.code_dtype]
 
-    pq_faiss = faiss.IndexPQ(D, pq_nanopq.M, nbits)
+    pq_faiss = faiss.IndexPQ(D, pq_nanopq.M, nbits, faiss_metric_map[pq_nanopq.metric])
 
     for m in range(pq_nanopq.M):
         # Prepare std::vector<float>
@@ -49,7 +56,7 @@ def nanopq_to_faiss(pq_nanopq):
 
 
 def faiss_to_nanopq(pq_faiss):
-    """Convert a `faiss.IndexPQ <https://github.com/facebookresearch/faiss/blob/master/IndexPQ.h>`_ 
+    """Convert a `faiss.IndexPQ <https://github.com/facebookresearch/faiss/blob/master/IndexPQ.h>`_
     or a `faiss.IndexPreTransform <https://github.com/facebookresearch/faiss/blob/master/IndexPreTransform.h>`_ instance to :class:`nanopq.OPQ`.
     To use this function, `faiss module needs to be installed <https://github.com/facebookresearch/faiss/blob/master/INSTALL.md>`_.
 
